#ifndef MSP_GL_SCENE_H_
#define MSP_GL_SCENE_H_

#include <list>
#include <msp/datafile/objectloader.h>
#include "matrix.h"
#include "renderable.h"
#include "vector.h"

namespace Msp {
namespace GL {

/**
Scenes are containers for other Renderables.  This is a base class that can't
be instantiated.  Examples of available Scene types are SimpleScene,
InstancedScene and OrderedScene.
*/
class Scene: public Renderable
{
public:
	class Loader: public DataFile::CollectionObjectLoader<Scene>
	{
	public:
		Loader(Scene &, Collection &);

	private:
		void object(const std::string &);
	};

protected:
	std::list<Renderable *> owned_data;
	mutable Matrix culling_matrix;
	mutable Vector4 frustum_edges[6];

	Scene() { }
private:
	Scene(const Scene &);
	Scene &operator=(const Scene &);
public:
	virtual ~Scene();

	virtual void add(Renderable &) = 0;
	virtual void remove(Renderable &) = 0;

protected:
	bool setup_frustum(const Renderer &) const;
	bool frustum_cull(const Renderable &) const;
};

} // namespace GL
} // namespace Msp

#endif
