#include "camera.h"
#include "renderable.h"
#include "renderer.h"
#include "view.h"

namespace Msp {
namespace GL {

View::View():
	target(Framebuffer::system()),
	camera(0),
	content(0)
{ }

void View::set_camera(Camera *c)
{
	camera = c;
	if(camera)
		camera->set_aspect(get_aspect());
}

void View::set_content(Renderable *r)
{
	content = r;
}

void View::synchronize_camera_aspect(Camera &c)
{
	synced_cameras.push_back(&c);
	c.set_aspect(get_aspect());
}

void View::render()
{
	target.clear(COLOR_BUFFER_BIT|DEPTH_BUFFER_BIT);
	if(content)
	{
		Renderer renderer(camera);
		content->setup_frame(renderer);
		content->render(renderer);
		content->finish_frame();
	}
}

} // namespace GL
} // namespace Msp
