#ifndef MSP_GL_VIEW_H_
#define MSP_GL_VIEW_H_

#include <list>
#include "framebuffer.h"

namespace Msp {
namespace GL {

class Camera;
class Renderable;

/**
Manages the presentation of rendering results on the screen.
*/
class View: public sigc::trackable
{
protected:
	Framebuffer &target;
	Camera *camera;
	Renderable *content;
	std::list<Camera *> synced_cameras;

	View();

public:
	virtual unsigned get_width() const { return target.get_width(); }
	virtual unsigned get_height() const { return target.get_height(); }
	float get_aspect() const { return static_cast<float>(get_width())/get_height(); }

	void set_camera(Camera *);
	void set_content(Renderable *);

	// Deprecated
	void synchronize_camera_aspect(Camera &);

	virtual void render();
};

} // namespace GL
} // namespace Msp

#endif
